@@ -170,6 +170,10 @@ class AdversarialTexturePyTorch(EvasionAttack):
                 y=None,
             )
 
+        self._patch.grad = torch.zeros(
+            self._patch.grad.shape, device=self._patch.grad.device, dtype=self._patch.grad.dtype
+        )
+
         with torch.no_grad():
             self._patch[:] = torch.clamp(
                 self._patch + gradients, min=self.estimator.clip_values[0], max=self.estimator.clip_values[1]
