@@ -376,7 +376,7 @@ class AutoProjectedGradientDescent(EvasionAttack):
         mask = kwargs.get("mask")
 
         if y is not None:
-            y = check_and_transform_label_format(y, self.estimator.nb_classes)
+            y = check_and_transform_label_format(y, nb_classes=self.estimator.nb_classes)
 
         if y is None:
             if self.targeted:
