@@ -133,7 +133,7 @@ class HopSkipJump(EvasionAttack):
             # Use model predictions as correct outputs
             y = get_labels_np_array(self.estimator.predict(x, batch_size=self.batch_size))  # type: ignore
 
-        y = check_and_transform_label_format(y, self.estimator.nb_classes)
+        y = check_and_transform_label_format(y, nb_classes=self.estimator.nb_classes)
 
         if self.estimator.nb_classes == 2 and y.shape[1] == 1:  # pragma: no cover
             raise ValueError(
