@@ -132,7 +132,7 @@ class OverTheAirFlickeringPyTorch(EvasionAttack):
         import torch  # lgtm [py/repeated-import]
 
         if y is not None:
-            y = check_and_transform_label_format(y, self.estimator.nb_classes)
+            y = check_and_transform_label_format(y, nb_classes=self.estimator.nb_classes)
         if y is None:
             if self.targeted:  # pragma: no cover
                 raise ValueError("Target labels `y` need to be provided for a targeted attack.")
