@@ -142,7 +142,7 @@ class Wasserstein(EvasionAttack):
         :return: An array holding the adversarial examples.
         """
         if y is not None:
-            y = check_and_transform_label_format(y, self.estimator.nb_classes)
+            y = check_and_transform_label_format(y, nb_classes=self.estimator.nb_classes)
         x_adv = x.copy().astype(ART_NUMPY_DTYPE)
 
         if y is None:
