@@ -25,7 +25,7 @@ gradients.
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 import logging
-from typing import Optional, Tuple, TYPE_CHECKING
+from typing import Optional, Tuple, Any, TYPE_CHECKING
 
 import numpy as np
 from scipy.ndimage import zoom
@@ -211,7 +211,7 @@ class ZooAttack(EvasionAttack):
         :return: An array holding the adversarial examples.
         """
         if y is not None:
-            y = check_and_transform_label_format(y, self.estimator.nb_classes)
+            y = check_and_transform_label_format(y, nb_classes=self.estimator.nb_classes)
 
         # Check that `y` is provided for targeted attacks
         if self.targeted and y is None:  # pragma: no cover
@@ -310,11 +310,9 @@ class ZooAttack(EvasionAttack):
         :return: A tuple of three batches of updated constants and lower/upper bounds.
         """
 
-        def compare(object1, object2):
-            return object1 == object2 if self.targeted else object1 != object2
-
         comparison = [
-            compare(best_label[i], np.argmax(y_batch[i])) and best_label[i] != -np.inf for i in range(len(c_batch))
+            self._compare(best_label[i], np.argmax(y_batch[i])) and best_label[i] != -np.inf
+            for i in range(len(c_batch))
         ]
         for i, comp in enumerate(comparison):
             if comp:
@@ -329,6 +327,18 @@ class ZooAttack(EvasionAttack):
 
         return c_batch, c_lower_bound, c_upper_bound
 
+    def _compare(self, object1: Any, object2: Any) -> bool:
+        """
+        Check two objects for equality if the attack is targeted, otherwise check for inequality.
+
+        :param object1: First object to compare.
+        :param object2: Second object to compare.
+        :return: When the attack is targeted, returns "True" if object are equal otherwise "False". When the attack is
+                    untargeted, the function returns "True" when the objects are different otherwise "False".
+
+        """
+        return object1 == object2 if self.targeted else object1 != object2
+
     def _generate_bss(
         self, x_batch: np.ndarray, y_batch: np.ndarray, c_batch: np.ndarray
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
@@ -341,9 +351,6 @@ class ZooAttack(EvasionAttack):
         :return: A tuple of best elastic distances, best labels, best attacks.
         """
 
-        def compare(object1, object2):
-            return object1 == object2 if self.targeted else object1 != object2
-
         x_orig = x_batch.astype(ART_NUMPY_DTYPE)
         fine_tuning = np.full(x_batch.shape[0], False, dtype=bool)
         prev_loss = 1e6 * np.ones(x_batch.shape[0])
@@ -415,7 +422,7 @@ class ZooAttack(EvasionAttack):
             # Adjust the best result
             labels_batch = np.argmax(y_batch, axis=1)
             for i, (dist, pred) in enumerate(zip(l2dist, np.argmax(preds, axis=1))):
-                if dist < best_dist[i] and compare(pred, labels_batch[i]):
+                if dist < best_dist[i] and self._compare(pred, labels_batch[i]):
                     best_dist[i] = dist
                     best_attack[i] = x_adv[i]
                     best_label[i] = pred
@@ -528,6 +535,16 @@ class ZooAttack(EvasionAttack):
     ) -> np.ndarray:
         """
         Implementation of the ADAM optimizer for coordinate descent.
+
+        :param losses: Overall loss.
+        :param index: Indices of the coordinates to update.
+        :param mean: The mean of the gradient (first moment).
+        :param var: The uncentered variance of the gradient (second moment).
+        :param current_noise: Current noise.
+        :param learning_rate: Learning rate for Adam optimizer.
+        :param adam_epochs: Epochs to run the Adam optimizer.
+        :param proj: Whether to project the noise to the L_p ball.
+        :return: Updated noise for coordinate descent.
         """
         beta1, beta2 = 0.9, 0.999
 
