@@ -43,15 +43,17 @@ logger = logging.getLogger(__name__)
 
 class CatBoostARTClassifier(ClassifierDecisionTree):
     """
-    Wrapper class for importing CatBoost models.
+    Class for importing CatBoost models.
     """
 
+    estimator_params = ClassifierDecisionTree.estimator_params + ["nb_features"]
+
     def __init__(
         self,
         model: Optional["CatBoostClassifier"] = None,
         preprocessing_defences: Union["Preprocessor", List["Preprocessor"], None] = None,
         postprocessing_defences: Union["Postprocessor", List["Postprocessor"], None] = None,
-        preprocessing: "PREPROCESSING_TYPE" = (0, 1),
+        preprocessing: "PREPROCESSING_TYPE" = (0.0, 1.0),
         clip_values: Optional["CLIP_VALUES_TYPE"] = None,
         nb_features: Optional[int] = None,
     ) -> None:
@@ -71,7 +73,7 @@ class CatBoostARTClassifier(ClassifierDecisionTree):
         # pylint: disable=E0611,E0401
         from catboost.core import CatBoostClassifier
 
-        if not isinstance(model, CatBoostClassifier):
+        if not isinstance(model, CatBoostClassifier):  # pragma: no cover
             raise TypeError("Model must be of type catboost.core.CatBoostClassifier")
 
         super().__init__(
@@ -83,7 +85,9 @@ class CatBoostARTClassifier(ClassifierDecisionTree):
         )
 
         self._input_shape = (nb_features,)
-        self._nb_classes = self._get_nb_classes()
+        nb_classes = self._get_nb_classes()
+        if nb_classes != -1:
+            self.nb_classes = nb_classes
 
     @property
     def input_shape(self) -> Tuple[int, ...]:
@@ -94,6 +98,15 @@ class CatBoostARTClassifier(ClassifierDecisionTree):
         """
         return self._input_shape  # type: ignore
 
+    @property
+    def nb_features(self) -> int:
+        """
+        Return the number of features.
+
+        :return: The number of features.
+        """
+        return self._input_shape[0]  # type: ignore
+
     def fit(self, x: np.ndarray, y: np.ndarray, **kwargs) -> None:
         """
         Fit the classifier on the training set `(x, y)`.
@@ -107,13 +120,13 @@ class CatBoostARTClassifier(ClassifierDecisionTree):
         x_preprocessed, y_preprocessed = self._apply_preprocessing(x, y, fit=True)
 
         self._model.fit(x_preprocessed, y_preprocessed, **kwargs)
-        self._nb_classes = self._get_nb_classes()
+        self.nb_classes = self._get_nb_classes()
 
     def predict(self, x: np.ndarray, **kwargs) -> np.ndarray:
         """
         Perform prediction for a batch of inputs.
 
-        :param x: Test set.
+        :param x: Input samples.
         :return: Array of predictions of shape `(nb_inputs, nb_classes)`.
         """
         # Apply preprocessing
@@ -151,7 +164,7 @@ class CatBoostARTClassifier(ClassifierDecisionTree):
         else:
             full_path = os.path.join(path, filename)
         folder = os.path.split(full_path)[0]
-        if not os.path.exists(folder):
+        if not os.path.exists(folder):  # pragma: no cover
             os.makedirs(folder)
 
         with open(full_path + ".pickle", "wb") as file_pickle:
