@@ -23,12 +23,13 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 from typing import Any, Dict, List, Optional, Union, Tuple, TYPE_CHECKING
 
+import numpy as np
+
 from art.estimators.generation.generator import GeneratorMixin
 from art.estimators.tensorflow import TensorFlowEstimator, TensorFlowV2Estimator
 
 if TYPE_CHECKING:
     # pylint: disable=C0412
-    import numpy as np
     import tensorflow.compat.v1 as tf
 
     from art.utils import CLIP_VALUES_TYPE, PREPROCESSING_TYPE
@@ -143,7 +144,7 @@ class TensorFlowGenerator(GeneratorMixin, TensorFlowEstimator):  # lgtm [py/miss
         """
         return self._feed_dict  # type: ignore
 
-    def predict(self, x: "np.ndarray", batch_size: int = 128, **kwargs) -> "np.ndarray":
+    def predict(self, x: np.ndarray, batch_size: int = 128, **kwargs) -> np.ndarray:
         """
         Perform projections over a batch of encodings.
 
@@ -158,7 +159,7 @@ class TensorFlowGenerator(GeneratorMixin, TensorFlowEstimator):  # lgtm [py/miss
         y = self._sess.run(self._model, feed_dict=feed_dict)
         return y
 
-    def loss_gradient(self, x, y, training_mode: bool = False, **kwargs) -> "np.ndarray":  # pylint: disable=W0221
+    def loss_gradient(self, x, y, training_mode: bool = False, **kwargs) -> np.ndarray:  # pylint: disable=W0221
         raise NotImplementedError
 
     def fit(self, x, y, batch_size=128, nb_epochs=10, **kwargs):
@@ -168,14 +169,14 @@ class TensorFlowGenerator(GeneratorMixin, TensorFlowEstimator):  # lgtm [py/miss
         raise NotImplementedError
 
     def get_activations(
-        self, x: "np.ndarray", layer: Union[int, str], batch_size: int, framework: bool = False
-    ) -> "np.ndarray":
+        self, x: np.ndarray, layer: Union[int, str], batch_size: int, framework: bool = False
+    ) -> np.ndarray:
         """
         Do nothing.
         """
         raise NotImplementedError
 
-    def compute_loss(self, x: "np.ndarray", y: "np.ndarray", **kwargs) -> "np.ndarray":
+    def compute_loss(self, x: np.ndarray, y: np.ndarray, **kwargs) -> np.ndarray:
         raise NotImplementedError
 
     @property
@@ -195,7 +196,7 @@ class TensorFlowGenerator(GeneratorMixin, TensorFlowEstimator):  # lgtm [py/miss
         return self._encoding_length
 
 
-class TensorFlow2Generator(GeneratorMixin, TensorFlowV2Estimator):  # lgtm [py/missing-call-to-init]
+class TensorFlowV2Generator(GeneratorMixin, TensorFlowV2Estimator):  # lgtm [py/missing-call-to-init]
     """
     This class implements a DGM with the TensorFlow framework.
     """
@@ -258,19 +259,35 @@ class TensorFlow2Generator(GeneratorMixin, TensorFlowV2Estimator):  # lgtm [py/m
     def input_shape(self) -> Tuple[int, ...]:
         raise NotImplementedError
 
-    def predict(self, x: "np.ndarray", batch_size: int = 128, **kwargs) -> "np.ndarray":
+    def predict(  # pylint: disable=W0221
+        self, x: np.ndarray, batch_size: int = 128, training_mode: bool = False, **kwargs
+    ) -> np.ndarray:
         """
         Perform projections over a batch of encodings.
 
         :param x: Encodings.
         :param batch_size: Batch size.
+        :param training_mode: `True` for model set to training mode and `'False` for model set to evaluation mode.
         :return: Array of prediction projections of shape `(num_inputs, nb_classes)`.
         """
-        logging.info("Projecting new sample from z value")
-        y = self._model(x)
-        return y
+        # Run prediction with batch processing
+        results_list = []
+        num_batch = int(np.ceil(len(x) / float(batch_size)))
+        for m in range(num_batch):
+            # Batch indexes
+            begin, end = (
+                m * batch_size,
+                min((m + 1) * batch_size, x.shape[0]),
+            )
 
-    def loss_gradient(self, x, y, **kwargs) -> "np.ndarray":
+            # Run prediction
+            results_list.append(self._model(x[begin:end], training=training_mode).numpy())
+
+        results = np.vstack(results_list)
+
+        return results
+
+    def loss_gradient(self, x, y, **kwargs) -> np.ndarray:
         raise NotImplementedError
 
     def fit(self, x, y, batch_size=128, nb_epochs=10, **kwargs):
@@ -280,8 +297,8 @@ class TensorFlow2Generator(GeneratorMixin, TensorFlowV2Estimator):  # lgtm [py/m
         raise NotImplementedError
 
     def get_activations(
-        self, x: "np.ndarray", layer: Union[int, str], batch_size: int, framework: bool = False
-    ) -> "np.ndarray":
+        self, x: np.ndarray, layer: Union[int, str], batch_size: int, framework: bool = False
+    ) -> np.ndarray:
         """
         Do nothing.
         """
