@@ -40,7 +40,7 @@ def fix_get_mnist_subset(get_mnist_dataset):
     yield x_train_mnist[:n_train], y_train_mnist[:n_train], x_test_mnist[:n_test], y_test_mnist[:n_test]
 
 
-@pytest.mark.skipMlFramework("pytorch")
+@pytest.mark.skip_framework("pytorch")
 @pytest.mark.framework_agnostic
 def test_one_shot(art_warning, fix_get_mnist_subset, image_dl_estimator_for_attack):
     try:
@@ -61,7 +61,7 @@ def test_one_shot(art_warning, fix_get_mnist_subset, image_dl_estimator_for_atta
         art_warning(e)
 
 
-@pytest.mark.skipMlFramework("pytorch")
+@pytest.mark.skip_framework("pytorch")
 @pytest.mark.framework_agnostic
 def test_iterative_saliency(art_warning, fix_get_mnist_subset, image_dl_estimator_for_attack):
     try:
@@ -86,7 +86,7 @@ def test_iterative_saliency(art_warning, fix_get_mnist_subset, image_dl_estimato
         art_warning(e)
 
 
-@pytest.mark.skipMlFramework("pytorch")
+@pytest.mark.skip_framework("pytorch")
 @pytest.mark.framework_agnostic
 def test_iterative_saliency_refresh(art_warning, fix_get_mnist_subset, image_dl_estimator_for_attack):
     try:
@@ -111,6 +111,34 @@ def test_iterative_saliency_refresh(art_warning, fix_get_mnist_subset, image_dl_
         art_warning(e)
 
 
+@pytest.mark.framework_agnostic
+def test_check_params(art_warning, image_dl_estimator_for_attack):
+    try:
+        from art.attacks.evasion import FastGradientMethod
+
+        classifier = image_dl_estimator_for_attack(FrameSaliencyAttack, from_logits=True)
+
+        attacker = FastGradientMethod(estimator=classifier)
+
+        with pytest.raises(ValueError):
+            _ = FrameSaliencyAttack(classifier, attacker="attack")
+
+        with pytest.raises(ValueError):
+            _ = FrameSaliencyAttack(classifier, attacker=attacker, method="test")
+
+        with pytest.raises(ValueError):
+            _ = FrameSaliencyAttack(classifier, attacker=attacker, frame_index=0)
+
+        with pytest.raises(ValueError):
+            _ = FrameSaliencyAttack(classifier, attacker=attacker, batch_size=-1)
+
+        with pytest.raises(ValueError):
+            _ = FrameSaliencyAttack(classifier, attacker=attacker, verbose="true")
+
+    except ARTTestException as e:
+        art_warning(e)
+
+
 @pytest.mark.framework_agnostic
 def test_classifier_type_check_fail(art_warning):
     try:
