@@ -26,6 +26,7 @@ import tensorflow as tf
 from art.attacks.evasion.projected_gradient_descent.projected_gradient_descent import ProjectedGradientDescent
 from art.attacks.evasion.projected_gradient_descent.projected_gradient_descent_numpy import (
     ProjectedGradientDescentNumpy,
+    ProjectedGradientDescentCommon,
 )
 from art.estimators.classification import KerasClassifier
 from art.estimators.estimator import BaseEstimator, LossGradientsMixin
@@ -69,6 +70,49 @@ class TestPGD(TestBase):
             classifier, self.x_train_mnist, self.y_train_mnist, self.x_test_mnist, self.y_test_mnist
         )
 
+    def test_check_params(self):
+
+        krc = get_image_classifier_kr(from_logits=True)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, norm=-1)
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescentCommon(krc, eps="1", eps_step=0.1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, eps=-1)
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescentCommon(krc, eps=np.array([-1]))
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, eps_step=-1)
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescentCommon(krc, eps_step=np.array([-1]))
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, eps=np.array([1.0, 1.0]), eps_step=np.array([1.0]))
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, targeted="False")
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescentCommon(krc, num_random_init="1")
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, num_random_init=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, batch_size=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, max_iter=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescentCommon(krc, verbose="False")
+
     def test_3_tensorflow_mnist(self):
         classifier, sess = get_image_classifier_tf()
 
@@ -113,7 +157,7 @@ class TestPGD(TestBase):
         x_test_original = x_test.copy()
 
         # Test PGD with np.inf norm
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, verbose=False)
         x_train_adv = attack.generate(x_train)
         x_test_adv = attack.generate(x_test)
 
@@ -133,7 +177,7 @@ class TestPGD(TestBase):
         logger.info("Accuracy on adversarial test examples: %.2f%%", acc * 100)
 
         # Test PGD with 3 random initialisations
-        attack = ProjectedGradientDescent(classifier, num_random_init=3)
+        attack = ProjectedGradientDescent(classifier, num_random_init=3, verbose=False)
         x_train_adv = attack.generate(x_train)
         x_test_adv = attack.generate(x_test)
 
@@ -156,7 +200,7 @@ class TestPGD(TestBase):
         self.assertAlmostEqual(float(np.max(np.abs(x_test_original - x_test))), 0.0, delta=0.00001)
 
         # Test the masking
-        attack = ProjectedGradientDescent(classifier, num_random_init=1)
+        attack = ProjectedGradientDescent(classifier, num_random_init=1, verbose=False)
         mask = np.random.binomial(n=1, p=0.5, size=np.prod(x_test.shape))
         mask = mask.reshape(x_test.shape).astype(np.float32)
 
@@ -165,7 +209,7 @@ class TestPGD(TestBase):
         self.assertAlmostEqual(float(np.max(np.abs(mask_diff))), 0.0, delta=0.00001)
 
         # Test eps of array type 1
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, verbose=False)
 
         eps = np.ones(shape=x_test.shape) * 1.0
         eps_step = np.ones_like(eps) * 0.1
@@ -225,7 +269,7 @@ class TestPGD(TestBase):
         classifier = get_tabular_classifier_kr()
 
         # Test untargeted attack
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris)
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -238,7 +282,7 @@ class TestPGD(TestBase):
 
         # Test targeted attack
         targets = random_targets(self.y_test_iris, nb_classes=3)
-        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -254,7 +298,7 @@ class TestPGD(TestBase):
 
         # Recreate a classifier without clip values
         classifier = KerasClassifier(model=classifier._model, use_logits=False, channels_first=True)
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.2, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.2, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris)
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv > 1).any())
@@ -269,7 +313,7 @@ class TestPGD(TestBase):
         classifier, _ = get_tabular_classifier_tf()
 
         # Test untargeted attack
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris)
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -282,7 +326,7 @@ class TestPGD(TestBase):
 
         # Test targeted attack
         targets = random_targets(self.y_test_iris, nb_classes=3)
-        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -297,7 +341,7 @@ class TestPGD(TestBase):
         classifier = get_tabular_classifier_pt()
 
         # Test untargeted attack
-        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris)
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -310,7 +354,7 @@ class TestPGD(TestBase):
 
         # Test targeted attack
         targets = random_targets(self.y_test_iris, nb_classes=3)
-        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5)
+        attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
         self.assertFalse((self.x_test_iris == x_test_adv).all())
         self.assertTrue((x_test_adv <= 1).all())
@@ -340,7 +384,7 @@ class TestPGD(TestBase):
             classifier.fit(x=self.x_test_iris, y=self.y_test_iris)
 
             # Test untargeted attack
-            attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5)
+            attack = ProjectedGradientDescent(classifier, eps=1.0, eps_step=0.1, max_iter=5, verbose=False)
             x_test_adv = attack.generate(self.x_test_iris)
             self.assertFalse((self.x_test_iris == x_test_adv).all())
             self.assertTrue((x_test_adv <= 1).all())
@@ -356,7 +400,9 @@ class TestPGD(TestBase):
 
             # Test targeted attack
             targets = random_targets(self.y_test_iris, nb_classes=3)
-            attack = ProjectedGradientDescent(classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5)
+            attack = ProjectedGradientDescent(
+                classifier, targeted=True, eps=1.0, eps_step=0.1, max_iter=5, verbose=False
+            )
             x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
             self.assertFalse((self.x_test_iris == x_test_adv).all())
             self.assertTrue((x_test_adv <= 1).all())
@@ -399,6 +445,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist)
@@ -413,6 +460,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist)
@@ -436,6 +484,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist)
@@ -450,6 +499,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist)
@@ -473,6 +523,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist)
@@ -487,6 +538,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist)
@@ -510,6 +562,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist, self.y_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist, self.y_test_mnist)
@@ -524,6 +577,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist, self.y_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist, self.y_test_mnist)
@@ -548,6 +602,7 @@ class TestPGD(TestBase):
             num_random_init=2,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist)
@@ -563,6 +618,7 @@ class TestPGD(TestBase):
             num_random_init=2,
             batch_size=3,
             random_eps=False,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist)
@@ -587,6 +643,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
         x_train_adv_np = attack_np.generate(self.x_train_mnist)
         x_test_adv_np = attack_np.generate(self.x_test_mnist)
@@ -602,6 +659,7 @@ class TestPGD(TestBase):
             num_random_init=0,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
         x_train_adv_fw = attack_fw.generate(self.x_train_mnist)
         x_test_adv_fw = attack_fw.generate(self.x_test_mnist)
@@ -626,6 +684,7 @@ class TestPGD(TestBase):
             num_random_init=1,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
 
         mask = np.random.binomial(n=1, p=0.5, size=np.prod(self.x_train_mnist.shape))
@@ -647,6 +706,7 @@ class TestPGD(TestBase):
             num_random_init=1,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
 
         mask = np.random.binomial(n=1, p=0.5, size=np.prod(self.x_train_mnist.shape))
@@ -677,6 +737,7 @@ class TestPGD(TestBase):
             num_random_init=1,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
 
         mask = np.random.binomial(n=1, p=0.5, size=np.prod(self.x_train_mnist.shape[1:]))
@@ -698,6 +759,7 @@ class TestPGD(TestBase):
             num_random_init=1,
             batch_size=3,
             random_eps=True,
+            verbose=False,
         )
 
         mask = np.random.binomial(n=1, p=0.5, size=np.prod(self.x_train_mnist.shape[1:]))
@@ -716,6 +778,43 @@ class TestPGD(TestBase):
             np.mean(x_test_adv_np - self.x_test_mnist), np.mean(x_test_adv_fw - self.x_test_mnist), places=6
         )
 
+    def test_check_params_pt(self):
+
+        ptc = get_image_classifier_pt(from_logits=True)
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescent(ptc, eps=np.array([1, 1, 1]), eps_step=1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, norm=0)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, eps=-1, eps_step=1)
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, eps=np.array([-1, -1, -1]), eps_step=np.array([1, 1, 1]))
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, eps=1, eps_step=-1)
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, eps=np.array([1, 1, 1]), eps_step=np.array([-1, -1, -1]))
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, targeted="true")
+
+        with self.assertRaises(TypeError):
+            _ = ProjectedGradientDescent(ptc, num_random_init=1.0)
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, num_random_init=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, batch_size=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, max_iter=-1)
+
+        with self.assertRaises(ValueError):
+            _ = ProjectedGradientDescent(ptc, verbose="true")
+
 
 if __name__ == "__main__":
     unittest.main()
