@@ -40,12 +40,12 @@ def test_wrong_parameters(params, art_warning, get_default_mnist_subset, image_d
 
         classifier.fit(x_train_mnist[:NB_TRAIN], y_train_mnist[:NB_TRAIN], nb_epochs=1)
         with pytest.raises(ValueError):
-            defence = SpectralSignatureDefense(classifier, x_train_mnist[:NB_TRAIN], y_train_mnist[:NB_TRAIN], **params)
+            _ = SpectralSignatureDefense(classifier, x_train_mnist[:NB_TRAIN], y_train_mnist[:NB_TRAIN], **params)
     except ARTTestException as e:
         art_warning(e)
 
 
-@pytest.mark.skipMlFramework("non_dl_frameworks", "mxnet")
+@pytest.mark.skip_framework("non_dl_frameworks", "mxnet")
 def test_detect_poison(art_warning, get_default_mnist_subset, image_dl_estimator):
     try:
         (x_train_mnist, y_train_mnist), (_, _) = get_default_mnist_subset
@@ -66,7 +66,7 @@ def test_detect_poison(art_warning, get_default_mnist_subset, image_dl_estimator
         art_warning(e)
 
 
-@pytest.mark.skipMlFramework("non_dl_frameworks", "mxnet")
+@pytest.mark.skip_framework("non_dl_frameworks", "mxnet")
 def test_evaluate_defense(art_warning, get_default_mnist_subset, image_dl_estimator):
     try:
         (x_train_mnist, y_train_mnist), (_, _) = get_default_mnist_subset
@@ -82,6 +82,6 @@ def test_evaluate_defense(art_warning, get_default_mnist_subset, image_dl_estima
             eps_multiplier=EPS_MULTIPLIER,
             expected_pp_poison=UB_PCT_POISON,
         )
-        res = defence.evaluate_defence(np.zeros(NB_TRAIN))
+        _ = defence.evaluate_defence(np.zeros(NB_TRAIN))
     except ARTTestException as e:
         art_warning(e)
