@@ -24,13 +24,14 @@ import numpy as np
 
 from art.estimators.classification.classifier import ClassGradientsMixin, ClassifierMixin
 from art.estimators.estimator import BaseEstimator, LossGradientsMixin, NeuralNetworkMixin
-from art.utils import Deprecated
 from tests.utils import TestBase, master_seed
 
 logger = logging.getLogger(__name__)
 
 
 class ClassifierInstance(ClassifierMixin, BaseEstimator):
+    estimator_params = BaseEstimator.estimator_params + ClassifierMixin.estimator_params
+
     def __init__(self, clip_values=None, channels_first=True):
         super(ClassifierInstance, self).__init__(model=None, clip_values=clip_values)
 
@@ -53,6 +54,10 @@ class ClassifierInstance(ClassifierMixin, BaseEstimator):
 class ClassifierNeuralNetworkInstance(
     ClassGradientsMixin, ClassifierMixin, NeuralNetworkMixin, LossGradientsMixin, BaseEstimator
 ):
+    estimator_params = (
+        BaseEstimator.estimator_params + NeuralNetworkMixin.estimator_params + ClassifierMixin.estimator_params
+    )
+
     def __init__(self, clip_values, channels_first=True):
         super(ClassifierNeuralNetworkInstance, self).__init__(
             model=None, clip_values=clip_values, channels_first=channels_first
@@ -67,7 +72,7 @@ class ClassifierNeuralNetworkInstance(
     def get_activations(self, x, layer, batch_size):
         pass
 
-    def loss(self, x, y, **kwargs):
+    def compute_loss(self, x, y, **kwargs):
         pass
 
     def loss_gradient(self, x, y, **kwargs):
@@ -85,9 +90,6 @@ class ClassifierNeuralNetworkInstance(
     def layer_names(self):
         pass
 
-    def set_learning_phase(self, train):
-        pass
-
     def input_shape(self):
         pass
 
@@ -118,7 +120,7 @@ class TestClassifier(TestBase):
         self.assertIn("clip_values=None", repr_)
         self.assertIn("defences=None", repr_)
         self.assertIn(
-            "preprocessing=[StandardisationMeanStd(mean=0, std=1, apply_fit=True, apply_predict=True)]", repr_
+            "preprocessing=StandardisationMeanStd(mean=0.0, std=1.0, apply_fit=True, apply_predict=True)", repr_
         )
 
 
@@ -143,11 +145,11 @@ class TestClassifierNeuralNetwork(TestBase):
         classifier = ClassifierNeuralNetworkInstance((0, 1))
         repr_ = repr(classifier)
         self.assertIn("ClassifierNeuralNetworkInstance", repr_)
-        self.assertIn(f"channel_index={Deprecated}, channels_first=True", repr_)
+        self.assertIn("channels_first=True", repr_)
         self.assertIn("clip_values=[0. 1.]", repr_)
         self.assertIn("defences=None", repr_)
         self.assertIn(
-            "preprocessing=[StandardisationMeanStd(mean=0, std=1, apply_fit=True, apply_predict=True)]", repr_
+            "preprocessing=StandardisationMeanStd(mean=0.0, std=1.0, apply_fit=True, apply_predict=True)", repr_
         )
 
 
